@@ -656,7 +656,7 @@ void print_header_month_line_stdout( const header_info header, const int coloriz
 	/**************************************************
 	*  print padding
 	*************************************************/
-	for (j = 1; j < padding; j++) printf(" ");
+	for (j = 1; j < (int)padding; j++) printf(" ");
 
 
 	/**************************************************
@@ -1051,6 +1051,9 @@ void print_week( int jd, const int month, const option_list opt)
 		if (opt.shabbat)
 		{
 			// candlelighting times
+			/// note: compiler incorrectly issued warnings:
+			///    "may be used uninitialized in this function [-Wmaybe-uninitialized]"
+			///    The initialization occurs above (~line 1005) "yom_shishi = h"
 			hdate_get_utc_sun_time (yom_shishi.gd_day, yom_shishi.gd_mon, yom_shishi.gd_year,
 									opt.lat, opt.lon, &sunrise, &sunset);
 
@@ -1135,7 +1138,7 @@ void print_week( int jd, const int month, const option_list opt)
 					// padding - FIXME - spaces are single-byte, while
 					// the Hebrew characters are two bytes
 					const int margin_max = 15;
-					printf("%*s%s", (margin_max - shabbat_name_str_len/2)," ", shabbat_name_buffer);
+					printf("%*s%s", (int)(margin_max - shabbat_name_str_len/2)," ", shabbat_name_buffer);
 
 					free(shabbat_name_buffer);
 				}
@@ -1158,9 +1161,13 @@ int print_calendar ( const int current_month, const int current_year, const opti
 	hdate_struct h;
 	int calendar_line;
 	int max_calendar_lines = 4;
-	int previous_month, next_month;
+	/// the initializations on next line aren't truly necessary, but they do
+	/// suppress warning "may be used uninitialized in this function [-Wmaybe-uninitialized]"
+	int previous_month = 1, next_month = 1;
 	int previous_year, next_year;
-	int jd_current_month, jd_previous_month, jd_next_month;
+	/// the initializations on next line aren't truly necessary, but they do
+	/// suppress warning "may be used uninitialized in this function [-Wmaybe-uninitialized]"
+	int jd_current_month, jd_previous_month = 1, jd_next_month = 1;
 
 	void how_many_calendar_lines( int month, int start_dow )
 	{
@@ -1181,6 +1188,8 @@ int print_calendar ( const int current_month, const int current_year, const opti
 		case 12:	if (start_dow > 5) max_calendar_lines = 6;
 					else if (max_calendar_lines == 4) max_calendar_lines = 5;
 					break;
+		case  2:	if (start_dow > 1 && max_calendar_lines == 4) max_calendar_lines = 5;
+					break;
 		}
 	}
 
@@ -1344,7 +1353,7 @@ int print_month ( const int month, const int year, const option_list opt)
 					// padding - FIXME - spaces are single-byte, while
 					// the Hebrew characters are two bytes
 					const int margin_max = 16; // 15 fails because of jabotinsky in july
-					printf("%*s%s\n", (margin_max - holiday_str_len/2)," ", holiday_buffer);
+					printf("%*s%s\n", (int)(margin_max - holiday_str_len/2)," ", holiday_buffer);
 
 					free(holiday_buffer);
 				}
