@@ -38,6 +38,10 @@
 #include <string.h>		// For mempcpy
 #include <getopt.h>		// For optarg, optind
 #include <stdio.h>		// For printf, fopen, fclose, fprintf, snprintf. FILE
+#include <pwd.h>		// for get pwuid
+#include <unistd.h>		// for getuid
+#include <sys/stat.h>
+#include <sys/types.h>	// for mkdir,
 
 
 // support for fnmatch
@@ -248,11 +252,11 @@ void revstr( char *source, const size_t source_len)
 
 #define DEBUG 0
 #if DEBUG
-printf("\nrevstr: entry: sourcelen = %d, source = %s\n",source_len, source);
+printf("\nrevstr: entry: sourcelen = %ld, source = %s\n",source_len, source);
 #endif
 
 	if (source == NULL) {error(0,0,"revstr: source buffer pointer is NULL"); exit(0);};
-	if (source_len <= 0) {error(0,0,"revstr: source_len parameter invalid, %d",source_len); exit(0);};
+	if (source_len <= 0) {error(0,0,"revstr: source_len parameter invalid, %ld",source_len); exit(0);};
 
 	size_t i,j;
 	char *temp_buff;
@@ -273,7 +277,7 @@ printf("\nrevstr: entry: sourcelen = %d, source = %s\n",source_len, source);
 	memcpy(source, temp_buff, source_len);
 	source[source_len] = '\0';
 #if DEBUG
-printf("\nrevstr: before free(tempbuff): sourcelen = %d, source = %s\n",source_len, source);
+printf("\nrevstr: before free(tempbuff): sourcelen = %ld, source = %s\n",source_len, source);
 #endif
 	free(temp_buff);
 	return;
@@ -651,11 +655,6 @@ FILE* get_config_file(	const char* config_dir_name,
 						const char* config_file_name,
 						const char* default_config_file_text )
 {
-#include <pwd.h>			// for get pwuid
-#include <unistd.h>			// for getuid
-#include <sys/stat.h>
-#include <sys/types.h>		// for mkdir,
-
 	size_t path_len;
 
 	char* config_home_path_name = "";
@@ -677,7 +676,7 @@ FILE* get_config_file(	const char* config_dir_name,
 			error(0, errno, "%s: %s", N_("failure attempting to create config file"), config_file_path);
 			return;
 		}
-		fprintf(config_file, default_config_file_text);
+		fprintf(config_file, "%s", default_config_file_text);
 		error(0,0,"%s: %s",N_("config file created"), config_file_path);
 		if (fclose(config_file) != 0) error(0,errno,"%s %s",N_("failure closing"),config_file_name);
 	}
